summaryrefslogtreecommitdiff
path: root/examples/pubsub_client.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/pubsub_client.py')
-rwxr-xr-xexamples/pubsub_client.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/pubsub_client.py b/examples/pubsub_client.py
index 9a65553b..56135ec1 100755
--- a/examples/pubsub_client.py
+++ b/examples/pubsub_client.py
@@ -6,22 +6,22 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
-from sleekxmpp.xmlstream import ET, tostring
+import slixmpp
+from slixmpp.xmlstream import ET, tostring
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class PubsubClient(sleekxmpp.ClientXMPP):
+class PubsubClient(slixmpp.ClientXMPP):
def __init__(self, jid, password, server,
node=None, action='list', data=''):
@@ -6,22 +6,22 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):